#!/usr/bin/env python
# -*- coding: utf-8 -*-

import requests

class CVESearch(object):

	_session = None
	__DEFAULT_BASE_URL = "https://cve.circl.lu/api/"
	__DEFAULT_TIMEOUT = 120

	def __init__(self, base_url = __DEFAULT_BASE_URL, request_timeout = __DEFAULT_TIMEOUT):
		self.base_url = base_url
		self.request_timeout = request_timeout
		self.session = self._create_session()

	@staticmethod
	def _create_session():
		session = requests.Session()
		user_agent = 'ares - python wrapper around cve.circl.lu (github.com/barnumbirr/ares)'
		session.headers.update({'Content-Type': 'application/json'})
		session.headers.update({'User-agent': user_agent})
		return session

	def __request(self, endpoint, query):
		# There is probably a more elegant way to do this ¯\_(ツ)_/¯
		if query:
			response = self.session.get(requests.compat.urljoin(self.base_url, endpoint + query),
		                                timeout = self.request_timeout)
		else:
			response = self.session.get(requests.compat.urljoin(self.base_url, endpoint),
		                                timeout = self.request_timeout)

		response.raise_for_status()
		return response.json()

	def browse(self, param=None):
		return self.__request('browse/', query=param)

	def capec(self, param):
		return self.__request('capec/', query=param)

	# def cpe22(self, param):
	# 	return self.__request('cpe2.2/', query=param)

	# def cpe23(self, param):
	# 	return self.__request('cpe2.3/', query=param)

	# def cvefor(self, param):
	# 	return self.__request('cvefor/', query=param)

	def cwe(self):
		""" Outputs a list of all CWEs (Common Weakness Enumeration). """
		return self.__request('cwe', query=None)

	def dbinfo(self):
		return self.__request('dbInfo', query=None)

	def id(self, param):
		return self.__request('cve/', query=param)

	def last(self, param=None):
		return self.__request('last/', query=param)

	# def link(self, param):
	# 	return self.__request('link/', query=param)

	# def search(self, param):
	# 	return self.__request('search/', query=param)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# To use a consistent encoding
from os import path
from codecs import open
# Always prefer setuptools over distutils
try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='ares',
    packages = ['ares'],
    version = '0.6.1',
    description = 'Python wrapper around https://cve.circl.lu.',
    author = 'Martin Simon',
    author_email = 'me@martinsimon.me',
    url = 'https://github.com/barnumbirr/ares',
    project_urls={
        'Bug Reports': 'https://github.com/barnumbirr/ares/issues',
        'Buy me a coffee': 'https://github.com/barnumbirr/ares#buy-me-a-coffee',
    },
    license = 'Apache v2.0 License',
    keywords=['CVE', 'cybersecurity', 'vulnerability', 'circl.lu'],
    classifiers=[
        'License :: OSI Approved :: Apache Software License',
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.7',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    long_description = long_description,
    long_description_content_type='text/markdown',
)
